@@ -53,11 +53,13 @@ class TitleBar : public QWidget
 
 
     protected:
-        void resizeEvent(QResizeEvent*) Q_DECL_OVERRIDE;
-        void paintEvent(QPaintEvent*) Q_DECL_OVERRIDE;
+        void resizeEvent(QResizeEvent*) override;
+        void paintEvent(QPaintEvent*) override;
 
 
     private:
+        void moveButtons();
+
         MainWindow* m_mainWindow;
         Skin* m_skin;
 
